@@ -1542,9 +1542,10 @@ sub download_file_and_sig {
         uscan_verbose "Don't check OpenPGP signature";
     } elsif ($self->pgpmode eq 'gittag') {
         if ($skip_git_vrfy) {
-            uscan_warn "File already downloaded, skipping gpg verification";
+            uscan_warn
+              "File already downloaded, skipping OpenPGP verification";
         } elsif (!$self->keyring) {
-            uscan_warn "No keyring file, skipping gpg verification";
+            uscan_warn "No keyring file, skipping OpenPGP verification";
             return $self->status(1);
         } else {
             my ($gitrepo, $gitref) = split /[[:space:]]+/, $self->upstream_url;
