@@ -205,7 +205,7 @@ Options:
   --[no]multimaint-merge
          When appending an entry to a changelog section, [do not] merge the
          entry into an existing changelog section for the current author.
-         (default: do not)
+         (default: do merge)
   -m, --maintmaint
          Don\'t change (maintain) the maintainer details in the changelog entry
   -M, --controlmaint
@@ -264,7 +264,7 @@ my $opt_query                 = 1;
 my $opt_release_heuristic     = 'changelog';
 my $opt_release_heuristic_re  = '^(changelog|log)$';
 my $opt_multimaint            = 1;
-my $opt_multimaint_merge      = 0;
+my $opt_multimaint_merge      = 1;
 my $opt_tz                    = undef;
 my $opt_t                     = '';
 my $opt_allow_lower           = '';
@@ -289,7 +289,7 @@ if (@ARGV and $ARGV[0] =~ /^--no-?conf$/) {
         'DEBCHANGE_RELEASE_HEURISTIC'    => 'changelog',
         'DEBCHANGE_MULTIMAINT'           => 'yes',
         'DEBCHANGE_TZ'                   => $ENV{TZ},       # undef if TZ unset
-        'DEBCHANGE_MULTIMAINT_MERGE'     => 'no',
+        'DEBCHANGE_MULTIMAINT_MERGE'     => 'yes',
         'DEBCHANGE_MAINTTRAILER'         => '',
         'DEBCHANGE_LOWER_VERSION_PATTERN' => '',
         'DEBCHANGE_AUTO_NMU'              => 'yes',
@@ -323,7 +323,7 @@ if (@ARGV and $ARGV[0] =~ /^--no-?conf$/) {
     $config_vars{'DEBCHANGE_MULTIMAINT'} =~ /^(yes|no)$/
       or $config_vars{'DEBCHANGE_MULTIMAINT'} = 'yes';
     $config_vars{'DEBCHANGE_MULTIMAINT_MERGE'} =~ /^(yes|no)$/
-      or $config_vars{'DEBCHANGE_MULTIMAINT_MERGE'} = 'no';
+      or $config_vars{'DEBCHANGE_MULTIMAINT_MERGE'} = 'yes';
     $config_vars{'DEBCHANGE_AUTO_NMU'} =~ /^(yes|no)$/
       or $config_vars{'DEBCHANGE_AUTO_NMU'} = 'yes';
     $config_vars{'DEBCHANGE_FORCE_SAVE_ON_RELEASE'} =~ /^(yes|no)$/
@@ -676,7 +676,7 @@ my $EMAIL        = 'EMAIL';
 my $DISTRIBUTION = 'UNRELEASED';
 # when updating the lines below also update the help text, the manpage and the testcases.
 my %dists       = (10, 'buster', 11, 'bullseye', 12, 'bookworm', 13, 'trixie');
-my $lts_dist    = '10';
+my $lts_dist    = '11';
 my $latest_dist = '12';
 # dist guessed from backports, SRU, security uploads...
 my $guessed_dist = '';
@@ -938,7 +938,7 @@ if (
 
         if (    $maintainer !~ m/<packages\@qa\.debian\.org>/
             and !grep { $_ eq $packager } ($maintainer, @uploaders)
-              and $packager ne $changelog->{Maintainer}
+            and $packager ne $changelog->{Maintainer}
             and !$opt_team) {
             $opt_n = 1;
             $opt_a = 0;
